@@ -11,11 +11,11 @@ Perl::Critic::Bangs - A collection of handy Perl::Critic policies
 
 =head1 VERSION
 
-Version 1.06
+Version 1.08
 
 =cut
 
-our $VERSION = '1.06';
+our $VERSION = '1.08';
 
 =head1 SYNOPSIS
 
@@ -50,7 +50,7 @@ a cut-n-paste that is incorrect.
 =head2 L<Perl::Critic::Policy::Bangs::ProhibitUselessRegexModifiers>
 
 Adding modifiers to a regular expression made up entirely of a
-variable created with qr() is usually not doing what you expect.
+variable created with C<qr()> is usually not doing what you expect.
 
 =head2 L<Perl::Critic::Policy::Bangs::ProhibitVagueNames>
 
@@ -122,24 +122,18 @@ Thanks to
 
 =item * Oystein Torget for bug reports and patches.
 
+=item * Mike O'Regan for ProhibitBitwiseOperators.
+
+=item * Elliot Shank and the rest of the Perl::Critic team for ongoing support.
+
 =back
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT
 
-Copyright 2006-2010 Andy Lester.
+Copyright 2006-2011 Andy Lester.
 
 This program is free software; you can redistribute it and/or modify
-it under the terms of either:
-
-=over 4
-
-=item * the GNU General Public License as published by the Free
-Software Foundation; either version 1, or (at your option) any later
-version, or
-
-=item * the Artistic License version 2.0.
-
-=back
+it under the terms of the Artistic License 2.0.
 
 =cut
 
