@@ -5,7 +5,7 @@ use warnings;
 use Perl::Critic::Utils;
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.06';
+our $VERSION = '1.08';
 
 #---------------------------------------------------------------------------
 
@@ -15,7 +15,7 @@ sub supported_parameters {
             name           => 'commentedcoderegex',
             description    => 'Regular expression to use to look for code in comments.',
             behavior       => 'string',
-            default_string => '\$[A-Za-z_].*=', ## no critic
+            default_string => '\$[A-Za-z_].*=', ## no critic (RequireInterpolationOfMetachars)
         },
     );
 }
@@ -86,14 +86,9 @@ Based on App::Fluff by Andy Lester, "<andy at petdance.com>"
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006-2010 Andy Lester and Andrew Moore
+Copyright (C) 2006-2011 Andy Lester and Andrew Moore
 
 This library is free software; you can redistribute it and/or modify
-it under the terms of either the GNU Public License v3, or the Artistic
-License 2.0.
-
-    * http://www.gnu.org/copyleft/gpl.html
-
-    * http://www.opensource.org/licenses/artistic-license-2.0.php
+it under the terms of the Artistic License 2.0.
 
 =cut
