@@ -5,7 +5,7 @@ use warnings;
 use Perl::Critic::Utils;
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.06';
+our $VERSION = '1.08';
 
 sub supported_parameters { return ()                     }
 sub default_severity     { return $SEVERITY_HIGH         }
@@ -31,8 +31,8 @@ sub violates {
             # this is where I test to see if the thing after the || is the same as the thing before the ref
             if ( $or->snext_sibling() eq $suspectproto->content() ) {
                 # here it looks like we have ref $proto || $proto
-                my $desc = q("ref $proto || $proto" construct found); ## no critic
-                my $expl = q(Probably cut-and-pasted example code);
+                my $desc = q{"ref $proto || $proto" construct found}; ## no critic (RequireInterpolationOfMetachars)
+                my $expl = q{Probably cut-and-pasted example code};
                 return $self->violation( $desc, $expl, $elem );
             }
         }
@@ -110,14 +110,9 @@ and work done by Andrew Moore <amoore@mooresystems.com>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006-2009 Andy Lester
+Copyright (C) 2006-2011 Andy Lester
 
-This library is free software; you can redistribute it and/or modify
-it under the terms of either the GNU Public License v3, or the Artistic
-License 2.0.
-
-    * http://www.gnu.org/copyleft/gpl.html
-
-    * http://www.opensource.org/licenses/artistic-license-2.0.php
+This library is free software; you can redistribute it and/or modify it
+under the terms of the Artistic License 2.0.
 
 =cut
