@@ -5,10 +5,9 @@ use warnings;
 use Readonly;
 
 use Perl::Critic::Utils qw{ :severities :classification :ppi };
-use Perl::Critic::Utils::PPIRegexp qw{ &get_modifiers &get_match_string };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.06';
+our $VERSION = '1.08';
 
 Readonly::Scalar my $DESC => q{Prohibits adding "m" modifier to compiled regular expressions where it does nothing};
 Readonly::Scalar my $EXPL => <<'EOF';
@@ -35,9 +34,9 @@ sub violates {
     # 1) there's an 'm' modifier
     # 2) the *only* thing in the regex is a compiled regex from a previous qr().
     # 3) the modifiers are not the same in both places
-    my %mods = get_modifiers($elem);
+    my %mods = $elem->get_modifiers();
     if ( $mods{'m'} || $mods{'s'} ) {
-        my $match = get_match_string( $elem );
+        my $match = $elem->get_match_string();
         if ( $match =~ /^\$\w+$/smx ) {  # It looks like a single variable in there
             if ( my $qr = _previously_assigned_quote_like_operator( $elem, $match ) ) {
                 # don't violate if both regexes are modified in the same way
@@ -79,7 +78,7 @@ sub _find_previous_quote_like_regexp {
 sub _sorted_modifiers {
     my $elem = shift;
 
-    my %mods = get_modifiers( $elem );
+    my %mods = $elem->get_modifiers();
     return join( '', sort keys %mods );
 }
 
@@ -102,11 +101,13 @@ incorrectly applied. This was fixed in 5.10, but no warnings were
 emitted to warn the user that they were probably not getting the
 effects they are looking for.
 
-correct:
+Correct:
+
   my $regex = qr(abc)m;
   if ( $string =~ /$regex/ ) {};
 
-Not what you want::
+Not what you want:
+
   my $regex = qr(abc);
   if ( $string =~ /$regex/m ) {}; ## this triggers a violation of this policy.
 
@@ -133,15 +134,10 @@ Thanks to Andy Lester, "<andy at petdance.com>" for pointing out this common pro
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2009 Andy Lester <andy@petdance.com> and Andrew
+Copyright (c) 2007-2011 Andy Lester <andy@petdance.com> and Andrew
 Moore <amoore@mooresystems.com>
 
-This library is free software; you can redistribute it and/or modify
-it under the terms of either the GNU Public License v3, or the Artistic
-License 2.0.
-
-    * http://www.gnu.org/copyleft/gpl.html
-
-    * http://www.opensource.org/licenses/artistic-license-2.0.php
+This library is free software; you can redistribute it and/or modify it
+under the terms of the Artistic License 2.0.
 
 =cut
